summaryrefslogtreecommitdiffstats
path: root/parameter/SubsystemObject.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /parameter/SubsystemObject.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'parameter/SubsystemObject.h')
-rwxr-xr-xparameter/SubsystemObject.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/parameter/SubsystemObject.h b/parameter/SubsystemObject.h
index 1b37201..ab085bc 100755
--- a/parameter/SubsystemObject.h
+++ b/parameter/SubsystemObject.h
@@ -32,6 +32,8 @@
#include "Syncer.h"
#include <stdint.h>
+#include <string>
+
class CInstanceConfigurableElement;
class CMappingContext;
class CSubsystem;
@@ -45,9 +47,9 @@ public:
/**
* Return the mapping value of the SubystemObject.
*
* @return A string containing the mapping value
*/
- virtual string getFormattedMappingValue() const;
+ virtual std::string getFormattedMappingValue() const;
// Configurable element retrieval
const CInstanceConfigurableElement* getConfigurableElement() const;
@@ -58,8 +60,8 @@ protected:
// Size
uint32_t getSize() const;
// Conversion utility
- static uint32_t asInteger(const string& strValue);
- static string asString(uint32_t uiValue);
+ static uint32_t asInteger(const std::string& strValue);
+ static std::string asString(uint32_t uiValue);
/**
* Conversion of int8, int16, int32 to int (taking care of sign extension)
@@ -73,22 +75,22 @@ protected:
int sizeOptimizedData);
// Sync to/from HW
- virtual bool sendToHW(string& strError);
- virtual bool receiveFromHW(string& strError);
+ virtual bool sendToHW(std::string& strError);
+ virtual bool receiveFromHW(std::string& strError);
// Fall back HW access
- virtual bool accessHW(bool bReceive, string& strError);
+ virtual bool accessHW(bool bReceive, std::string& strError);
// Blackboard access from subsystems
void blackboardRead(void* pvData, uint32_t uiSize);
void blackboardWrite(const void* pvData, uint32_t uiSize);
// Logging
- void log_info(const string& strMessage, ...) const;
- void log_warning(const string& strMessage, ...) const;
+ void log_info(const std::string& strMessage, ...) const;
+ void log_warning(const std::string& strMessage, ...) const;
// Belonging Subsystem retrieval
const CSubsystem* getSubsystem() const;
private:
// from ISyncer
- virtual bool sync(CParameterBlackboard& parameterBlackboard, bool bBack, string& strError);
+ virtual bool sync(CParameterBlackboard& parameterBlackboard, bool bBack, std::string& strError);
// Default back synchronization
void setDefaultValues(CParameterBlackboard& parameterBlackboard) const;
@@ -45,9 +47,9 @@ public:
* Return the mapping value of the SubystemObject.
*
- * @return A string containing the mapping value
+ * @return A std::string containing the mapping value
*/